summaryrefslogtreecommitdiffstats
path: root/test/filter_fail.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/filter_fail.c')
-rw-r--r--test/filter_fail.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/filter_fail.c b/test/filter_fail.c
index c7248cc..f165d8a 100644
--- a/test/filter_fail.c
+++ b/test/filter_fail.c
@@ -349,8 +349,8 @@ error:
* Purpose: Tests the library's behavior when a mandate filter returns
* failure.
*
* Return: Success: exit(0)
* Failure: exit(1)
*
* Programmer: Raymond Lu
* 25 August 2010
@@ -406,6 +406,6 @@ error:
if (nerrors) {
printf("***** %u FAILURE%s! *****\n",
nerrors, 1==nerrors?"":"S");
- HDexit(1);
+ HDexit(EXIT_FAILURE);
}
}
@@ -349,8 +349,8 @@ error:
* failure.
*
- * Return: Success: exit(0)
- * Failure: exit(1)
+ * Return: Success: exit(EXIT_SUCCESS)
+ * Failure: exit(EXIT_FAILURE)
*
* Programmer: Raymond Lu